@@ -17,7 +17,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include/forms.h"
@@ -38,7 +38,7 @@ set_spinner_return( FL_OBJECT *,
  * This function got to be called before a redraw, at least if
  * the form the spinner belongs to has been resized or proper-
  * ties of the spinner have been changed. It calculates the
- * new positions and sizes of the objectes the spinner widget
+ * new positions and sizes of the objects the spinner widget
  * is made up from.
  ***************************************/
 
@@ -75,7 +75,7 @@ set_geom( FL_OBJECT * obj )
     {
         bwh = obj->w / 2;
         bwh = FL_max( bwh, 1 );
-        obj->w = sp->input->w = 2 * bwh;
+        obj->w = 2 * bwh;
 
         sp->input->x = obj->x;
         sp->input->y = obj->y;
@@ -109,7 +109,7 @@ set_geom( FL_OBJECT * obj )
  * react to. If it got resized the positions and sizes of the child
  * objects it's made up from need to be recalculated, but that can
  * be deferred until it's redrawn. Drawing it works mostly auto-
- * matically except the redraw of the label. And on deletion just
+ * matically except the redraw of the label. And on deletion only
  * the FLI_SPINNER_SPEC needs to be deallocated (the child objects
  * referenced there-in have already been deallocated before).
  ***************************************/
@@ -120,7 +120,7 @@ handle_spinner( FL_OBJECT * obj,
                 FL_Coord    mx   FL_UNUSED_ARG,
                 FL_Coord    my   FL_UNUSED_ARG,
                 int         key  FL_UNUSED_ARG,
-                void *      ev   FL_UNUSED_ARG )
+                void      * ev   FL_UNUSED_ARG )
 {
     FLI_SPINNER_SPEC *sp = obj->spec;
 
@@ -128,6 +128,7 @@ handle_spinner( FL_OBJECT * obj,
     {
         case FL_ATTRIB :
         case FL_RESIZED :
+            obj->align = fl_to_outside_lalign( obj->align );
             sp->attrib = 1;
             break;
 
@@ -138,12 +139,14 @@ handle_spinner( FL_OBJECT * obj,
                 sp->attrib = 0;
             }
 
+            /* fall through */
+
         case FL_DRAWLABEL :
             fl_draw_object_label_outside( obj );
             break;
 
         case FL_FREEMEM :
-            fl_safe_free( obj->spec );
+            fli_safe_free( obj->spec );
             break;
     }
 
@@ -164,21 +167,26 @@ spinner_callback( FL_OBJECT * obj,
     FLI_SPINNER_SPEC *sp = obj->parent->spec;
     const char *s_val = fl_get_input( sp->input );
     int max_len = 4 + sp->prec + log10( DBL_MAX );
-    char buf[ max_len ];
+    char *buf = NULL;
 
-    if ( data == 0 && ! *s_val && ! ( obj->returned & FL_RETURN_END ) )
+    /* Don't react to editing the input field unless user ended interaction
+       with input field */
+
+    if ( data == 0 && ! ( obj->returned & FL_RETURN_END ) )
         return;
 
+    obj->parent->returned = FL_RETURN_NONE;
+
     if ( obj->parent->type == FL_INT_SPINNER )
     { 
         int old_i_val = sp->i_val;
 
-        if ( data == 0 )
+        if ( data == 0 )    /* spinners input object was modified */
         {
             char *eptr;
             long i_val = strtol( s_val, &eptr, 10 );
 
-            /* heck for an invalid value entered */
+            /* Check for an invalid value entered */
 
             if ( eptr == s_val || i_val > sp->i_max || i_val < sp->i_min )
             {
@@ -208,27 +216,25 @@ spinner_callback( FL_OBJECT * obj,
                 sp->i_val = sp->i_min;
         }
 
+        buf = fl_malloc( max_len );
         sprintf( buf, "%d", sp->i_val );
         fl_set_input( sp->input, buf );
+        fl_free( buf );
+        buf = NULL;
 
-        if ( obj->returned & FL_RETURN_END )
-            obj->parent->returned |= FL_RETURN_END;
-
-        if ( sp->i_val != old_i_val )
+        if ( data != 0 )
+        {
+            if ( sp->i_val != old_i_val )
+                obj->parent->returned |= FL_RETURN_CHANGED;
+        }
+        else if ( obj->returned & FL_RETURN_END && sp->i_val != sp->old_ival )
             obj->parent->returned |= FL_RETURN_CHANGED;
 
-        if (    sp->i_val != sp->old_ival
-             && data != 0
-             && obj->returned & FL_RETURN_END )
-            obj->parent->returned |= FL_RETURN_CHANGED | FL_RETURN_END;
-
-        if ( obj->parent->returned & FL_RETURN_END )
+        if ( obj->returned & FL_RETURN_END )
+        {
+            obj->parent->returned |= FL_RETURN_END;
             sp->old_ival = sp->i_val;
-
-        if ( obj->parent->how_return & FL_RETURN_END_CHANGED
-             && ! (    obj->parent->returned & FL_RETURN_CHANGED
-                    && obj->parent->returned & FL_RETURN_END ) )
-            obj->parent->returned = FL_RETURN_NONE;
+        }
     }
     else
     {
@@ -267,27 +273,25 @@ spinner_callback( FL_OBJECT * obj,
                 sp->f_val = sp->f_min;
         }
 
+        buf = malloc( max_len );
         sprintf( buf, "%.*f", sp->prec, sp->f_val );
         fl_set_input( sp->input, buf );
+        fl_free( buf );
+        buf = NULL;
 
-        if ( obj->returned & FL_RETURN_END )
-            obj->parent->returned |= FL_RETURN_END;
-
-        if ( sp->f_val != old_f_val )
+        if ( data != 0 )
+        {
+            if ( sp->f_val != old_f_val )
+                obj->parent->returned |= FL_RETURN_CHANGED;
+        }
+        else if ( obj->returned & FL_RETURN_END && sp->f_val != sp->old_fval )
             obj->parent->returned |= FL_RETURN_CHANGED;
 
-        if (    sp->f_val != sp->old_fval
-             && data != 0
-             && obj->returned & FL_RETURN_END )
-            obj->parent->returned |= FL_RETURN_CHANGED | FL_RETURN_END;
-
-        if ( obj->parent->returned & FL_RETURN_END )
+        if ( obj->returned & FL_RETURN_END )
+        {
+            obj->parent->returned |= FL_RETURN_END;
             sp->old_fval = sp->f_val;
-
-        if ( obj->parent->how_return & FL_RETURN_END_CHANGED
-             && ! (    obj->parent->returned & FL_RETURN_CHANGED
-                    && obj->parent->returned & FL_RETURN_END ) )
-            obj->parent->returned = FL_RETURN_NONE;
+        }
     }
 }
 
@@ -305,34 +309,7 @@ fl_create_spinner( int          type,
 {
     FL_OBJECT *obj;
     FLI_SPINNER_SPEC *sp;
-    FL_Coord iw, ih,
-             ux, uy,
-             dx, dy,
-             bwh;
-    int orient;
-
-    if ( w >= h )
-    {
-        orient = 0;
-        bwh = h / 2;
-        bwh = FL_max( bwh, 1 );
-        h = ih = 2 * bwh;
-        iw = w - bwh - 1;
-        ux = dx = x + iw - 1;
-        uy = x;
-        dy = uy + bwh;
-    }
-    else
-    {
-        orient = 1;
-        bwh = w / 2;
-        bwh = FL_max( bwh, 1 );
-        w = iw = 2 * bwh;
-        ih = h - bwh - 1;
-        dx = x;
-        ux = dx + bwh;
-        uy = dy = y + ih - 1;
-    }
+    int orient = ( w < h );
 
     obj = fl_make_object( FL_SPINNER, type, x, y, w, h, label, handle_spinner );
     obj->boxtype    = FL_NO_BOX;
@@ -358,8 +335,8 @@ fl_create_spinner( int          type,
     fl_set_object_lcolor( sp->up,   FL_BLUE );
     fl_set_object_lcolor( sp->down, FL_BLUE );
 
-    obj->col1 = sp->input->col1;
-    obj->col2 = sp->input->col2;
+    obj->col1  = sp->input->col1;
+    obj->col2  = sp->input->col2;
 
     sp->i_val  = sp->old_ival = 0;
     sp->i_min  = - 10000;
@@ -409,6 +386,7 @@ fl_add_spinner( int          type,
 
 
 /***************************************
+ * Returns the spinner value
  ***************************************/
 
 double
@@ -440,10 +418,11 @@ fl_get_spinner_value( FL_OBJECT * obj )
         if ( *eptr )
         {
             int max_len = 4 + sp->prec + log10( DBL_MAX );
-            char buf[ max_len ];
+            char *buf = fl_malloc( max_len );
 
             sprintf( buf, "%.*f", sp->prec, f_val );
             fl_set_input( sp->input, buf );
+            fl_free( buf );
         }
 
         return sp->f_val = f_val;
@@ -452,6 +431,7 @@ fl_get_spinner_value( FL_OBJECT * obj )
 
 
 /***************************************
+ * Sets the spinner value
  ***************************************/
 
 double
@@ -459,8 +439,6 @@ fl_set_spinner_value( FL_OBJECT * obj,
                       double      val )
 {
     FLI_SPINNER_SPEC *sp = obj->spec;
-    int max_len = 4 + sp->prec + log10( DBL_MAX );
-    char buf[ max_len ];
 
     if ( obj->type == FL_INT_SPINNER )
     {
@@ -471,8 +449,7 @@ fl_set_spinner_value( FL_OBJECT * obj,
         else if ( val < sp->i_min )
             sp->i_val = sp->i_min;
 
-        sprintf( buf, "%d", sp->i_val );
-        fl_set_input( sp->input, buf );
+        fl_set_input_f( sp->input, "%d", sp->i_val );
 
         return sp->old_ival = sp->i_val;
     }
@@ -484,14 +461,14 @@ fl_set_spinner_value( FL_OBJECT * obj,
     else if ( val < sp->f_min )
         sp->f_val = sp->f_min;
 
-    sprintf( buf, "%.*f", sp->prec, sp->f_val );
-    fl_set_input( sp->input, buf );
+    fl_set_input_f( sp->input, "%.*f", sp->prec, sp->f_val );
 
     return sp->old_fval = sp->f_val;
 }
 
 
 /***************************************
+ * Sets the lower and upper bound of the spinner value
  ***************************************/
 
 void
@@ -500,13 +477,12 @@ fl_set_spinner_bounds( FL_OBJECT * obj,
                        double      max )
 {
     FLI_SPINNER_SPEC *sp = obj->spec;
-    double tmp;
 
     if ( min > max )
     {
-        tmp = min;
+        double tmp = min;
         min = max;
-        max = min;
+        max = tmp;
     }
 
     if ( obj->type == FL_INT_SPINNER )
@@ -549,6 +525,7 @@ fl_set_spinner_bounds( FL_OBJECT * obj,
 
 
 /***************************************
+ * Returns the lower and upper limit of the spinner value
  ***************************************/
 
 void
@@ -572,6 +549,9 @@ fl_get_spinner_bounds( FL_OBJECT * obj,
 
 
 /***************************************
+ * Sets the step size (increment or decrement value when the up
+ * or down button is clicked on) for the spinner. For FL_INT_SPINNER
+ * objects the number is rounded to the nearest integer.
  ***************************************/
 
 void
@@ -585,10 +565,15 @@ fl_set_spinner_step( FL_OBJECT * obj,
 
     if ( obj->type == FL_INT_SPINNER )
     {
-        if ( FL_nint( step ) > sp->i_max - sp->i_min )
+        int istep = FL_nint( step );
+
+        if ( istep == 0 )
+            istep = 1;
+
+        if ( istep > sp->i_max - sp->i_min )
             sp->i_incr = sp->i_max - sp->i_min;
         else
-            sp->i_incr = FL_nint( step );
+            sp->i_incr = istep;
     }
     else
     {
@@ -601,6 +586,8 @@ fl_set_spinner_step( FL_OBJECT * obj,
 
 
 /***************************************
+ * Returns the step size (increment or decrement value when the up
+ * or down button is clicked on) for the spinner 
  ***************************************/
 
 double
@@ -613,6 +600,8 @@ fl_get_spinner_step( FL_OBJECT * obj )
 
 
 /***************************************
+ * Sets the number of digits to be shown agter the decimal point (works
+ * on FL_FLOAT_SPINNER objects only)
  ***************************************/
 
 void
@@ -638,6 +627,8 @@ fl_set_spinner_precision( FL_OBJECT * obj,
 
 
 /***************************************
+ * Returns the number of digits shown after the decimal point
+ * (always returns 0 for FL_INT_SPINNER objects)
  ***************************************/
 
 int
@@ -651,6 +642,7 @@ fl_get_spinner_precision( FL_OBJECT * obj )
 
 
 /***************************************
+ * Returns the input sub-object
  ***************************************/
 
 FL_OBJECT *
@@ -661,6 +653,7 @@ fl_get_spinner_input( FL_OBJECT * obj )
 
 
 /***************************************
+ * Returns the button sub-object for raising the spinner value
  ***************************************/
 
 FL_OBJECT *
@@ -671,6 +664,7 @@ fl_get_spinner_up_button( FL_OBJECT * obj )
 
 
 /***************************************
+ * Returns the button sub-object for lowering the spinner value
  ***************************************/
 
 FL_OBJECT *
@@ -695,8 +689,8 @@ set_spinner_return( FL_OBJECT    * obj,
 
     obj->how_return = when;
     fl_set_object_return( sp->input, FL_RETURN_ALWAYS );
-    fl_set_object_return( sp->up,   FL_RETURN_CHANGED | FL_RETURN_END );
-    fl_set_object_return( sp->down, FL_RETURN_CHANGED | FL_RETURN_END );
+    fl_set_object_return( sp->up,    FL_RETURN_CHANGED | FL_RETURN_END );
+    fl_set_object_return( sp->down,  FL_RETURN_CHANGED | FL_RETURN_END );
 }
 
 
